@@ -20,7 +20,6 @@ gi.require_version('TotemPlParser', '1.0')
 from gi.repository import Gtk, Gio, GLib, Gdk, Notify, TotemPlParser
 
 from pickle import dump
-from locale import getlocale
 from gettext import gettext as _
 from threading import Thread
 
@@ -71,6 +70,18 @@ class Application(Gtk.Application):
                             flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE)
         GLib.setenv('PULSE_PROP_media.role', 'music', True)
         GLib.setenv('PULSE_PROP_application.icon_name', 'lollypop', True)
+
+        # Ideally, we will be able to delete this once Flatpak has a solution
+        # for SSL certificate management inside of applications.
+        if GLib.file_test("/app", GLib.FileTest.EXISTS):
+            paths = ["/etc/ssl/certs/ca-certificates.crt",
+                     "/etc/pki/tls/cert.pem",
+                     "/etc/ssl/cert.pem"]
+            for path in paths:
+                if GLib.file_test(path, GLib.FileTest.EXISTS):
+                    GLib.setenv('SSL_CERT_FILE', path, True)
+                    break
+
         self.cursors = {}
         self.window = None
         self.notify = None
@@ -169,15 +180,7 @@ class Application(Gtk.Application):
         Gtk.Application.do_startup(self)
         Notify.init("Lollypop")
 
-        # Check locale, we want unicode!
-        (code, encoding) = getlocale()
-        if encoding is None or encoding != "UTF-8":
-            builder = Gtk.Builder()
-            builder.add_from_resource('/org/gnome/Lollypop/Unicode.ui')
-            self.window = builder.get_object('unicode')
-            self.window.set_application(self)
-            self.window.show()
-        elif not self.window:
+        if not self.window:
             self.init()
             menu = self.__setup_app_menu()
             # If GNOME/Unity, add appmenu
@@ -263,6 +266,7 @@ class Application(Gtk.Application):
         self.player.stop_all()
         if self.window:
             self.window.stop_all()
+        self.charts.stop()
         self.quit()
 
     def quit(self):
@@ -347,7 +351,7 @@ class Application(Gtk.Application):
             value = options.lookup_value('set-rating').get_int32()
             if value > 0 and value < 6 and\
                     self.player.current_track.id is not None:
-                self.player.current_track.set_popularity(value)
+                self.player.current_track.set_rate(value)
         if options.contains('play-pause'):
             self.player.play_pause()
         elif options.contains('play-ids'):
