@@ -117,7 +117,7 @@ class CollectionScanner(GObject.GObject, TagReader):
             try:
                 d = Lio.File.new_for_uri(uri)
                 infos = d.enumerate_children(
-                    'standard::name,standard::type',
+                    'standard::name,standard::type,standard::is-hidden',
                     Gio.FileQueryInfoFlags.NONE,
                     None)
             except Exception as e:
@@ -127,7 +127,9 @@ class CollectionScanner(GObject.GObject, TagReader):
                 f = infos.get_child(info)
                 child_uri = f.get_uri()
                 empty = False
-                if info.get_file_type() == Gio.FileType.DIRECTORY:
+                if info.get_is_hidden():
+                    continue
+                elif info.get_file_type() == Gio.FileType.DIRECTORY:
                     track_dirs.append(child_uri)
                     walk_uris.append(child_uri)
                 else:
@@ -272,7 +274,9 @@ class CollectionScanner(GObject.GObject, TagReader):
         discnumber = self.get_discnumber(tags)
         discname = self.get_discname(tags)
         tracknumber = self.get_tracknumber(tags, name)
-        year = self.get_year(tags)
+        year = self.get_original_year(tags)
+        if year is None:
+            year = self.get_year(tags)
         duration = int(info.get_duration()/1000000000)
 
         # If no artists tag, use album artist
@@ -290,8 +294,8 @@ class CollectionScanner(GObject.GObject, TagReader):
 
         debug("CollectionScanner::add2db(): Restore stats")
         # Restore stats
-        (track_pop, track_ltime, amtime, album_pop) = self.__history.get(
-                                                            name, duration)
+        (track_pop, track_rate, track_ltime, amtime,
+         loved, album_pop, album_rate) = self.__history.get(name, duration)
         # If nothing in stats, set mtime
         if amtime == 0:
             amtime = mtime
@@ -308,7 +312,8 @@ class CollectionScanner(GObject.GObject, TagReader):
         debug("CollectionScanner::add2db(): Add album: "
               "%s, %s" % (album_name, album_artist_ids))
         (album_id, new_album) = self.add_album(album_name, album_artist_ids,
-                                               uri, album_pop, amtime, False)
+                                               uri, loved, album_pop,
+                                               album_rate, amtime, False)
 
         genre_ids = self.add_genres(genres, album_id)
 
@@ -316,7 +321,7 @@ class CollectionScanner(GObject.GObject, TagReader):
         debug("CollectionScanner::add2db(): Add track")
         track_id = Lp().tracks.add(title, uri, duration,
                                    tracknumber, discnumber, discname,
-                                   album_id, year, track_pop,
+                                   album_id, year, track_pop, track_rate,
                                    track_ltime, mtime)
 
         debug("CollectionScanner::add2db(): Update tracks")
@@ -344,13 +349,16 @@ class CollectionScanner(GObject.GObject, TagReader):
         album_artist_ids = Lp().albums.get_artist_ids(album_id)
         artist_ids = Lp().tracks.get_artist_ids(track_id)
         popularity = Lp().tracks.get_popularity(track_id)
+        rate = Lp().tracks.get_rate(track_id)
         ltime = Lp().tracks.get_ltime(track_id)
         mtime = Lp().albums.get_mtime(album_id)
         duration = Lp().tracks.get_duration(track_id)
         album_popularity = Lp().albums.get_popularity(album_id)
+        album_rate = Lp().albums.get_rate(album_id)
+        loved = Lp().albums.get_loved(album_id)
         uri = Lp().tracks.get_uri(track_id)
-        self.__history.add(name, duration, popularity,
-                           ltime, mtime, album_popularity)
+        self.__history.add(name, duration, popularity, rate,
+                           ltime, mtime, loved, album_popularity, album_rate)
         Lp().playlists.remove(uri)
         Lp().tracks.remove(track_id)
         Lp().tracks.clean(track_id)
