@@ -31,23 +31,26 @@ class AlbumsDatabase:
         self.__max_count = 1
         self._cached_randoms = []
 
-    def add(self, name, artist_ids, uri, popularity, mtime):
+    def add(self, name, artist_ids, uri, loved, popularity, rate, mtime):
         """
             Add a new album to database
             @param Album name as string
             @param artist ids as int
             @param uri as string
             @param mtime as int
+            @param loved as bool
+            @param popularity as int
+            @param rate as int
             @return inserted rowid as int
             @warning: commit needed
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("INSERT INTO albums\
                                   (name, no_album_artist,\
-                                  uri, popularity, mtime, synced)\
-                                  VALUES (?, ?, ?, ?, ?, ?)",
+                                  uri, loved, popularity, rate, mtime, synced)\
+                                  VALUES (?, ?, ?, ?, ?, ?, ?, ?)",
                                  (name, artist_ids == [],
-                                  uri, popularity, mtime, 0))
+                                  uri, loved, popularity, rate, mtime, 0))
             for artist_id in artist_ids:
                 sql.execute("INSERT INTO album_artists\
                              (album_id, artist_id)\
@@ -120,6 +123,28 @@ class AlbumsDatabase:
             sql.execute("UPDATE albums SET synced=? WHERE rowid=?",
                         (synced, album_id))
 
+    def set_loved(self, album_id, loved):
+        """
+            Set album loved
+            @param album id as int
+            @param loved as int
+            @warning: commit needed
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("UPDATE albums SET loved=? WHERE rowid=?",
+                        (loved, album_id))
+            sql.commit()
+
+    def set_rate(self, album_id, rate):
+        """
+            Set album rate
+            @param rate as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            sql.execute("UPDATE albums SET rate=? WHERE rowid=?",
+                        (rate, album_id))
+            sql.commit()
+
     def set_year(self, album_id, year):
         """
             Set year
@@ -181,6 +206,53 @@ class AlbumsDatabase:
                 return v[0]
             return 0
 
+    def get_loved(self, album_id):
+        """
+            Get album loved
+            @param album id as int
+            @return loved as bool
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT loved FROM albums WHERE\
+                                 rowid=?", (album_id,))
+
+            v = result.fetchone()
+            if v is not None:
+                return v[0]
+            return 0
+
+    def get_by_year(self, year):
+        """
+            Get albums with year
+            @param year as str
+        """
+        with SqlCursor(Lp().db) as sql:
+            filters = (Type.CHARTS, year)
+            request = "SELECT DISTINCT albums.rowid\
+                       FROM albums, album_genres\
+                       WHERE album_genres.genre_id!=?\
+                       AND year=?\
+                       AND album_genres.album_id=albums.rowid"
+            if not get_network_available():
+                request += " AND albums.synced!=%s" % Type.NONE
+            result = sql.execute(request, filters)
+            return list(itertools.chain(*result))
+
+    def get_rate(self, album_id):
+        """
+            Get album rate
+            @param album id as int
+            @return rate as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT rate FROM albums WHERE\
+                                 rowid=?", (album_id,))
+
+            v = result.fetchone()
+            if v is not None:
+                return v[0]
+            return Type.NONE
+
     def get_mtime(self, album_id):
         """
             Get modification time
@@ -412,7 +484,45 @@ class AlbumsDatabase:
                 return v[0]
             return 1
 
-    def get_populars(self):
+    def get_rated(self, limit=100):
+        """
+            Get albums with user rating >= 4
+            @param limit as int
+            @return array of album ids as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            filters = (Type.CHARTS, )
+            request = "SELECT DISTINCT albums.rowid\
+                       FROM albums, album_genres\
+                       WHERE album_genres.genre_id!=?\
+                       AND rate>=4\
+                       AND album_genres.album_id=albums.rowid"
+            if not get_network_available():
+                request += " AND albums.synced!=%s" % Type.NONE
+            request += " ORDER BY popularity DESC LIMIT %s" % limit
+            result = sql.execute(request, filters)
+            return list(itertools.chain(*result))
+
+    def get_populars(self, limit=100):
+        """
+            Get albums ids with popularity
+            @param limit as int
+            @return array of album ids as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            filters = (Type.CHARTS, )
+            request = "SELECT DISTINCT albums.rowid\
+                       FROM albums, album_genres\
+                       WHERE album_genres.genre_id!=?\
+                       AND popularity!=0\
+                       AND album_genres.album_id=albums.rowid"
+            if not get_network_available():
+                request += " AND albums.synced!=%s" % Type.NONE
+            request += " ORDER BY popularity DESC LIMIT %s" % limit
+            result = sql.execute(request, filters)
+            return list(itertools.chain(*result))
+
+    def get_loves(self):
         """
             Get albums ids with popularity
             @return array of album ids as int
@@ -422,10 +532,11 @@ class AlbumsDatabase:
             request = "SELECT DISTINCT albums.rowid\
                        FROM albums, album_genres\
                        WHERE album_genres.genre_id!=?\
+                       AND loved=1\
                        AND album_genres.album_id=albums.rowid"
             if not get_network_available():
                 request += " AND albums.synced!=%s" % Type.NONE
-            request += " ORDER BY popularity DESC LIMIT 100"
+            request += " ORDER BY popularity DESC"
             result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
