@@ -152,7 +152,7 @@ class ArtistsDatabase:
                 # Only artist that really have an album
                 result = sql.execute(
                                  "SELECT DISTINCT artists.rowid,\
-                                  artists.name\
+                                  artists.name, artists.sortname\
                                   FROM artists, albums,\
                                   album_genres, album_artists\
                                   WHERE album_artists.artist_id=artists.rowid\
@@ -165,7 +165,7 @@ class ArtistsDatabase:
             else:
                 genres = tuple(genre_ids)
                 request = "SELECT DISTINCT artists.rowid,\
-                           artists.name\
+                           artists.name, artists.sortname\
                            FROM artists, albums, album_genres, album_artists\
                            WHERE artists.rowid=album_artists.artist_id\
                            AND albums.rowid=album_artists.album_id\
@@ -175,7 +175,7 @@ class ArtistsDatabase:
                 request += "1=0) ORDER BY artists.sortname\
                             COLLATE NOCASE COLLATE LOCALIZED"
                 result = sql.execute(request, genres)
-            return [(row[0], row[1]) for row in result]
+            return [(row[0], row[1], row[2]) for row in result]
 
     def get_ids(self, genre_ids=[]):
         """
