@@ -170,6 +170,7 @@ class MPRIS(Server):
                                        None)
         Server.__init__(self, self.__bus, self.__MPRIS_PATH)
         Lp().player.connect('current-changed', self.__on_current_changed)
+        Lp().player.connect('rate-changed', self.__on_current_changed)
         Lp().player.connect('seeked', self.__on_seeked)
         Lp().player.connect('status-changed', self.__on_status_changed)
         Lp().player.connect('volume-changed', self.__on_volume_changed)
@@ -351,9 +352,10 @@ class MPRIS(Server):
             self.__metadata['xesam:url'] = GLib.Variant(
                                                  's',
                                                  Lp().player.current_track.uri)
-            self.__metadata["xesam:userRating"] = GLib.Variant(
-                                'd',
-                                Lp().player.current_track.get_popularity() / 5)
+            rate = Lp().player.current_track.get_rate()
+            if rate == Type.NONE:
+                rate = Lp().player.current_track.get_popularity()
+            self.__metadata["xesam:userRating"] = GLib.Variant('d', rate / 5)
             if Lp().player.current_track.id == Type.RADIOS:
                 cover_path = Lp().art.get_radio_cache_path(
                      ", ".join(Lp().player.current_track.artists),
