@@ -35,6 +35,7 @@ class MPRIS(dbus.service.Object):
         self._app = app
         self._metadata = {}
         Lp().player.connect('current-changed', self._on_current_changed)
+        Lp().player.connect('rate-changed', self._on_current_changed)
         Lp().player.connect('seeked', self._on_seeked)
         Lp().player.connect('status-changed', self._on_status_changed)
         Lp().player.connect('volume-changed', self._on_volume_changed)
@@ -183,8 +184,10 @@ class MPRIS(dbus.service.Object):
             self._metadata['xesam:genre'] = Lp().player.current_track.genres\
                 or "Web"
             self._metadata['xesam:url'] = Lp().player.current_track.uri
-            self._metadata["xesam:userRating"] = \
-                Lp().player.current_track.get_popularity() / 5
+            rate = Lp().player.current_track.get_rate()
+            if rate == Type.NONE:
+                rate = Lp().player.current_track.get_popularity()
+            self._metadata["xesam:userRating"] = GLib.Variant('d', rate / 5)
             if Lp().player.current_track.id == Type.RADIOS:
                 cover_path = Lp().art.get_radio_cache_path(
                      ", ".join(Lp().player.current_track.artists),
