@@ -13,6 +13,7 @@
 from gi.repository import Gio, GLib
 
 from pickle import load
+from random import choice
 
 from lollypop.player_bin import BinPlayer
 from lollypop.player_queue import QueuePlayer
@@ -47,16 +48,6 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         self.__do_not_update_next = False
         Lp().settings.connect('changed::playback', self.__on_playback_changed)
 
-    @property
-    def current_track(self):
-        """
-            Current track
-        """
-        if self._queue_track is not None:
-            return self._queue_track
-        else:
-            return self._current_track
-
     @property
     def next_track(self):
         """
@@ -96,7 +87,7 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         if self._locked:
             return
         if self._next_track.id is not None:
-            self._scrobble(self.current_track, self._start_time)
+            self._scrobble(self._current_track, self._start_time)
             self.load(self._next_track)
         else:
             self.stop()
@@ -262,7 +253,11 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         for artist_id in album.artist_ids:
             if artist_id >= 0:
                 self._context.artist_ids[album.id].append(artist_id)
-        self.load(album.tracks[0])
+        if Lp().settings.get_enum('shuffle') == Shuffle.TRACKS:
+            track = choice(album.tracks)
+        else:
+            track = album.tracks[0]
+        self.load(track)
         self._albums = [album.id]
 
     def set_albums(self, track_id, artist_ids, genre_ids):
@@ -300,6 +295,9 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         # We are in populars view, add popular albums
         elif genre_ids and genre_ids[0] == Type.POPULARS:
             self._albums = Lp().albums.get_populars()
+        # We are in loved view, add loved albums
+        elif genre_ids and genre_ids[0] == Type.LOVED:
+            self._albums = Lp().albums.get_loves()
         # We are in recents view, add recent albums
         elif genre_ids and genre_ids[0] == Type.RECENTS:
             self._albums = Lp().albums.get_recents()
@@ -443,7 +441,7 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         """
         try:
             if Lp().settings.get_enum('playback') == NextContext.REPEAT_TRACK:
-                self._prev_track = self.current_track
+                self._prev_track = self._current_track
             else:
                 # Look at externals
                 self._prev_track = ExternalsPlayer.prev(self)
@@ -478,7 +476,7 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             self._next_context = NextContext.NONE
 
             if Lp().settings.get_enum('playback') == NextContext.REPEAT_TRACK:
-                next_track = self.current_track
+                next_track = self._current_track
             else:
                 # Look at externals
                 next_track = ExternalsPlayer.next(self)
@@ -547,10 +545,13 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             Lp().window.pulse(False)
         if self._current_track.id is not None and self._current_track.id >= 0:
             ShufflePlayer._on_stream_start(self, bus, message)
-        if not self.__do_not_update_next:
-            self.set_next()
-        self.__do_not_update_next = False
-        self.set_prev()
+        if self.track_in_queue(self._current_track):
+            self.del_from_queue(self._current_track.id)
+        else:
+            if self.shuffle_has_next or not self.__do_not_update_next:
+                self.set_next()
+            self.__do_not_update_next = False
+            self.set_prev()
         BinPlayer._on_stream_start(self, bus, message)
 
 #######################
