@@ -14,10 +14,10 @@ from gi.repository import Gtk, GLib, Gdk, Pango, GObject
 
 from gettext import gettext as _
 
-from lollypop.pop_album import AlbumPopover
 from lollypop.view import LazyLoadingView
 from lollypop.define import Lp, ArtSize
 from lollypop.objects import Album
+from lollypop.view_albums import AlbumBackView
 
 
 class AlbumRow(Gtk.ListBoxRow):
@@ -273,6 +273,9 @@ class AlbumsView(LazyLoadingView):
     """
         View showing albums
     """
+    __gsignals__ = {
+        'album-activated': (GObject.SignalFlags.RUN_FIRST, None, (int,)),
+    }
 
     def __init__(self):
         """
@@ -329,12 +332,22 @@ class AlbumsView(LazyLoadingView):
         """
             Populate widget with album rows
         """
+        self._stop = False
         albums = list(Lp().player.get_albums())
         self.__jump_button.set_sensitive(False)
         if albums:
             self.__clear_button.set_sensitive(True)
         self.__add_items(albums)
 
+    def on_current_changed(self, player):
+        """
+            Show tracks in a popover
+            @param player object
+        """
+        for child in self.__view.get_children():
+            child.show_play_indicator(child.id ==
+                                      Lp().player.current_track.album.id)
+
 #######################
 # PRIVATE             #
 #######################
@@ -393,32 +406,18 @@ class AlbumsView(LazyLoadingView):
             Connect signals
             @param widget as Gtk.Widget
         """
-        self._stop = False
-        self.populate()
         self._signal_id1 = Lp().player.connect('current-changed',
-                                               self.__on_current_changed)
+                                               self.on_current_changed)
 
     def __on_unmap(self, widget):
         """
             Disconnect signals
             @param widget as Gtk.Widget
         """
-        self._stop = True
-        self._lazy_queue = []
-        GLib.idle_add(self.__clear)
         if self._signal_id1 is not None:
             Lp().player.disconnect(self._signal_id1)
             self._signal_id1 = None
 
-    def __on_current_changed(self, player):
-        """
-            Show tracks in a popover
-            @param player object
-        """
-        for child in self.__view.get_children():
-            child.show_play_indicator(child.id ==
-                                      Lp().player.current_track.album.id)
-
     def __on_child_destroyed(self, row):
         """
             Check clear button aspect
@@ -434,19 +433,7 @@ class AlbumsView(LazyLoadingView):
             @param widget as Gtk.ListBox
             @param row as AlbumRow
         """
-        genre_ids = Lp().player.get_genre_ids(row.id)
-        artist_ids = Lp().player.get_artist_ids(row.id)
-        # TODO Remove this later
-        if Gtk.get_minor_version() > 16:
-            popover = AlbumPopover(
-                                     row.id,
-                                     genre_ids,
-                                     [])
-            popover.set_relative_to(row)
-            popover.show()
-        else:
-            album = Album(row.id, genre_ids, artist_ids)
-            Lp().player.load(album.tracks[0])
+        self.emit('album-activated', row.id)
 
     def __on_jump_clicked(self, widget):
         """
@@ -528,15 +515,45 @@ class AlbumsPopover(Gtk.Popover):
             Init popover
         """
         Gtk.Popover.__init__(self)
+        self.__stack = Gtk.Stack()
+        self.__stack.set_transition_duration(250)
+        self.__stack.set_transition_type(Gtk.StackTransitionType.CROSSFADE)
+        self.__stack.show()
         view = AlbumsView()
+        view.connect('album-activated', self.__on_album_activated)
+        view.populate()
         view.show()
+        self.__stack.add_named(view, "albums_view")
         self.set_position(Gtk.PositionType.BOTTOM)
         self.connect('map', self.__on_map)
-        self.add(view)
+        self.add(self.__stack)
 
 #######################
 # PRIVATE             #
 #######################
+    def __on_album_activated(self, view, album_id):
+        """
+            Show album tracks
+            @param view as AlbumsView
+            @param album id as int
+        """
+        genre_ids = Lp().player.get_genre_ids(album_id)
+        artist_ids = Lp().player.get_artist_ids(album_id)
+        album_view = AlbumBackView(album_id, genre_ids, artist_ids)
+        album_view.connect('back-clicked', self.__on_back_clicked)
+        album_view.show()
+        self.__stack.add(album_view)
+        self.__stack.set_visible_child(album_view)
+
+    def __on_back_clicked(self, view):
+        """
+            Update album view for current track
+        """
+        albums_view = self.__stack.get_child_by_name("albums_view")
+        albums_view.on_current_changed(Lp().player)
+        self.__stack.set_visible_child(albums_view)
+        GLib.timeout_add(5000, view.destroy)
+
     def __on_map(self, widget):
         """
             Resize
