@@ -143,9 +143,10 @@ class ToolbarEnd(Gtk.Bin):
         Lp().set_accels_for_action("app.party", ["<Control>p"])
 
         self.__search_button = builder.get_object('search-button')
-        helper = TouchHelper(self.__search_button, "search", "<Control>f")
-        helper.set_long_func(self.__on_search_long)
-        helper.set_short_func(self.__on_search_short)
+        self.__helper = TouchHelper(self.__search_button,
+                                    "search", "<Control>f")
+        self.__helper.set_long_func(self.__on_search_long)
+        self.__helper.set_short_func(self.__on_search_short)
 
         self.__settings_button = builder.get_object('settings-button')
 
@@ -320,9 +321,14 @@ class ToolbarEnd(Gtk.Bin):
                 Gtk.IconSize.SMALL_TOOLBAR)
         elif shuffle == Shuffle.NONE:
             self.__shuffle_image.get_style_context().remove_class('selected')
-            self.__shuffle_image.set_from_icon_name(
-                "media-playlist-consecutive-symbolic",
-                Gtk.IconSize.SMALL_TOOLBAR)
+            if repeat == NextContext.NONE:
+                self.__shuffle_image.set_from_icon_name(
+                    "media-playlist-repeat-symbolic",
+                    Gtk.IconSize.SMALL_TOOLBAR)
+            else:
+                self.__shuffle_image.set_from_icon_name(
+                    "media-playlist-consecutive-symbolic",
+                    Gtk.IconSize.SMALL_TOOLBAR)
         else:
             self.__shuffle_image.set_from_icon_name(
                 "media-playlist-shuffle-symbolic",
