@@ -14,10 +14,11 @@ from gi.repository import Gtk, Gdk, Pango, GLib, Gio, GdkPixbuf
 
 from gettext import gettext as _
 from math import pi
+from random import choice
 
-from lollypop.define import Lp, ArtSize
+from lollypop.define import Lp, ArtSize, Shuffle
 from lollypop.utils import get_network_available
-from lollypop.objects import Track, Album
+from lollypop.objects import Album
 from lollypop.pop_info import InfoPopover
 from lollypop.cache import InfoCache
 from lollypop.pop_artwork import ArtworkPopover
@@ -167,7 +168,10 @@ class ArtistView(ArtistAlbumsView):
                 Lp().player.set_party(False)
             album_id = Lp().albums.get_ids(self._artist_ids,
                                            self._genre_ids)[0]
-            track = Track(Album(album_id).track_ids[0])
+            if Lp().settings.get_enum('shuffle') == Shuffle.TRACKS:
+                track = choice(Album(album_id).tracks)
+            else:
+                track = Album(album_id).tracks[0]
             Lp().player.load(track)
             Lp().player.set_albums(track.id, self._artist_ids,
                                    self._genre_ids)
@@ -301,6 +305,7 @@ class ArtistView(ArtistAlbumsView):
                                                                        size,
                                                                        True,
                                                                        None)
+                        stream.close()
                         surface = Gdk.cairo_surface_create_from_pixbuf(
                                             pixbuf, self.__scale_factor, None)
                         del pixbuf
